@@ -29,14 +29,15 @@ STATES = {
 }
 DEPENDS = ['state']
 LOCATION_DOMAIN = [
-    If(Eval('state').in_(['staging', 'draft', 'cancelled']),
+    If(Eval('state').in_(['staging', 'draft', 'cancelled'])
+        | ((Eval('state') == 'assigned') & ~Eval('quantity')),
         ('type', 'not in', ['warehouse']),
         ('type', 'not in', ['warehouse', 'view'])),
     If(~Eval('state').in_(['done', 'cancelled']),
         ('active', '=', True),
         ()),
     ]
-LOCATION_DEPENDS = ['state']
+LOCATION_DEPENDS = ['state', 'quantity']
 
 
 class StockMixin(object):
@@ -864,7 +865,8 @@ class Move(Workflow, ModelSQL, ModelView):
     @classmethod
     def delete(cls, moves):
         for move in moves:
-            if move.state not in {'staging', 'draft', 'cancelled'}:
+            if (move.state not in {'staging', 'draft', 'cancelled'}
+                    and move.quantity):
                 raise AccessError(
                     gettext('stock.msg_move_delete_draft_cancel',
                         move=move.rec_name))
@@ -1182,6 +1184,12 @@ class Move(Workflow, ModelSQL, ModelView):
         def get_column(name, table, product):
             if name.startswith('product.'):
                 column = Column(product, name[len('product.'):])
+            elif name == 'date':
+                return cls.effective_date.sql_cast(
+                    Coalesce(
+                        table.effective_date,
+                        Case((move.state == 'assigned', today), else_=Null),
+                        table.planned_date))
             else:
                 column = Column(table, name)
             return column.as_(name)
@@ -1298,6 +1306,11 @@ class Move(Workflow, ModelSQL, ModelView):
         if not context.get('stock_date_end'):
             context['stock_date_end'] = datetime.date.max
 
+        move_date = Coalesce(
+            move.effective_date,
+            Case((move.state == 'assigned', today), else_=Null),
+            move.planned_date)
+
         # date end in the past or today: filter on state done
         if (context['stock_date_end'] < today
                 or (context['stock_date_end'] == today
@@ -1306,17 +1319,7 @@ class Move(Workflow, ModelSQL, ModelView):
             def state_date_clause(stock_assign):
                 return (move.state.in_(['done',
                         'assigned' if stock_assign else 'done'])
-                    & (
-                        (
-                            (move.effective_date == Null)
-                            & (move.planned_date <= context['stock_date_end'])
-                            )
-                        | (move.effective_date <= context['stock_date_end'])
-                        | (move.state == (
-                                'assigned'
-                                if not context.get('stock_date_start')
-                                else ''))
-                        ))
+                    & (move_date <= context['stock_date_end']))
             state_date_clause_in = state_date_clause(False)
             state_date_clause_out = state_date_clause(
                 context.get('stock_assign'))
@@ -1327,41 +1330,12 @@ class Move(Workflow, ModelSQL, ModelView):
             def state_date_clause(stock_assign):
                 return ((move.state.in_(['done',
                                 'assigned' if stock_assign else 'done'])
-                        & (
-                            (
-                                (move.effective_date == Null)
-                                & (move.planned_date <= today)
-                                )
-                            | (move.effective_date <= today)
-                            | (move.state == (
-                                    'assigned'
-                                    if not context.get('stock_date_start')
-                                    else ''))
-                            )
-                        )
+                        & (move_date <= today))
                     | (move.state.in_(['done', 'assigned', 'draft'])
-                        & (
-                            (
-                                (move.effective_date == Null)
-                                & (Coalesce(
-                                        move.planned_date, datetime.date.max)
-                                    <= context['stock_date_end'])
-                                & (Coalesce(
-                                        move.planned_date, datetime.date.max)
-                                    >= today)
-                                )
-                            | (
-                                (move.effective_date
-                                    <= context['stock_date_end'])
-                                & (move.effective_date >= today)
-                                )
-                            | (move.state == (
-                                    'assigned'
-                                    if not context.get('stock_date_start')
-                                    else ''))
-                            )
-                        )
-                    )
+                        & (Coalesce(move_date, datetime.date.max)
+                            <= context['stock_date_end'])
+                        & (Coalesce(move_date, datetime.date.max) >= today)
+                        ))
             state_date_clause_in = state_date_clause(False)
             state_date_clause_out = state_date_clause(
                 context.get('stock_assign'))
@@ -1370,18 +1344,8 @@ class Move(Workflow, ModelSQL, ModelView):
             if context['stock_date_start'] > today:
                 def state_date_clause():
                     return (move.state.in_(['done', 'assigned', 'draft'])
-                        & (
-                            (
-                                (move.effective_date == Null)
-                                & (
-                                    (move.planned_date
-                                        >= context['stock_date_start'])
-                                    | (move.planned_date == Null)
-                                    )
-                                )
-                            | (move.effective_date
-                                >= context['stock_date_start'])
-                            )
+                        & (Coalesce(move_date, datetime.date.max)
+                            >= context['stock_date_start'])
                         )
                 state_date_clause_in &= state_date_clause()
                 state_date_clause_out &= state_date_clause()
@@ -1389,38 +1353,14 @@ class Move(Workflow, ModelSQL, ModelView):
                 def state_date_clause(stock_assign):
                     return ((
                             move.state.in_(['done', 'assigned', 'draft'])
-                            & (
-                                (
-                                    (move.effective_date == Null)
-                                    & (
-                                        (move.planned_date >= today)
-                                        | (move.planned_date == Null)
-                                        )
-                                    )
-                                | (move.effective_date >= today)
-                                )
+                            & (Coalesce(move_date, datetime.date.max) >= today)
                             )
                         | (
                             move.state.in_(['done',
                                     'assigned' if stock_assign else 'done'])
-                            & (
-                                (
-                                    (move.effective_date == Null)
-                                    & (
-                                        (
-                                            (move.planned_date
-                                                >= context['stock_date_start'])
-                                            & (move.planned_date < today)
-                                            )
-                                        | (move.planned_date == Null)
-                                        )
-                                    )
-                                | (
-                                    (move.effective_date
-                                        >= context['stock_date_start'])
-                                    & (move.effective_date < today)
-                                    )
-                                )
+                            & (Coalesce(move_date, datetime.date.max)
+                                >= context['stock_date_start'])
+                            & (Coalesce(move_date, datetime.date.min) < today)
                             )
                         )
                 state_date_clause_in &= state_date_clause(False)
@@ -1436,8 +1376,8 @@ class Move(Workflow, ModelSQL, ModelView):
                 period, = periods
 
                 def state_date_clause():
-                    return (Coalesce(move.effective_date, move.planned_date,
-                        datetime.date.max) > period.date)
+                    return (
+                        Coalesce(move_date, datetime.date.max) > period.date)
                 state_date_clause_in &= state_date_clause()
                 state_date_clause_out &= state_date_clause()
 
