@@ -24,7 +24,7 @@ from trytond.transaction import Transaction
 
 def pairwise(iterable):
     a, b = tee(iterable)
-    next(b)
+    next(b, None)
     return zip_longest(a, b)
 
 
